@@ -7,7 +7,7 @@ from algora.api.data.iex.stocks.__util import (
     _symbols_request_info, _historical_prices_request_info, _news_request_info, _peer_group_request_info
 )
 from algora.common.decorators import async_data_request
-from algora.common.function import transform_one_or_many, no_transform
+from algora.common.function import transform_one_or_many, no_transform, data_required_transform
 
 
 @async_data_request
@@ -22,7 +22,10 @@ async def async_symbols() -> DataFrame:
     return await __async_base_request(**request_info)
 
 
-@async_data_request(transformer=lambda d: transform_one_or_many(d, 'chart'))
+@async_data_request(transformers=[
+    data_required_transform,
+    lambda d: transform_one_or_many(d, 'chart')
+])
 async def async_historical_prices(*symbol: str, **kwargs) -> Union[DataFrame, Dict[str, DataFrame]]:
     """
     Asynchronous wrapper for IEX historical stock prices via
@@ -56,7 +59,7 @@ async def async_news(symbol: str, **kwargs) -> DataFrame:
     return await __async_base_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_peer_group(symbol: str) -> List[str]:
     """
     Asynchronous wrapper for [IEX stock peer group](https://iexcloud.io/docs/api/#peers).
