@@ -7,7 +7,7 @@ from algora.api.data.iex.stocks.__util import (
     _symbols_request_info, _historical_prices_request_info, _news_request_info, _peer_group_request_info
 )
 from algora.common.decorators import data_request
-from algora.common.function import transform_one_or_many, no_transform
+from algora.common.function import transform_one_or_many, no_transform, data_required_transform
 
 
 @data_request
@@ -22,7 +22,10 @@ def symbols() -> DataFrame:
     return __base_request(**request_info)
 
 
-@data_request(transformer=lambda d: transform_one_or_many(d, 'chart'))
+@data_request(transformers=[
+    data_required_transform,
+    lambda d: transform_one_or_many(d, 'chart')
+])
 def historical_prices(*symbol: str, **kwargs) -> Union[DataFrame, Dict[str, DataFrame]]:
     """
     Wrapper for IEX historical stock prices via
@@ -56,7 +59,7 @@ def news(symbol: str, **kwargs) -> DataFrame:
     return __base_request(**request_info)
 
 
-@data_request(transformer=no_transform)
+@data_request(transformers=[no_transform])
 def peer_group(symbol: str) -> List[str]:
     """
     Wrapper for [IEX stock peer group](https://iexcloud.io/docs/api/#peers).
