@@ -14,7 +14,7 @@ from algora.common.function import to_pandas_with_index, no_transform
 from algora.common.requests import __async_get_request
 
 
-@async_data_request(transformer=lambda data: to_pandas_with_index(data, index='execution_timestamp'))
+@async_data_request(transformers=[lambda data: to_pandas_with_index(data, index='execution_timestamp')])
 async def async_get_by_date(asset_class: AssetClass, date: str, repos: Optional[List[Repository]] = None) -> DataFrame:
     """
     Asynchronously get all SDR data by asset class, date and repositories.
@@ -31,7 +31,7 @@ async def async_get_by_date(asset_class: AssetClass, date: str, repos: Optional[
     return await __async_get_request(**request_info)
 
 
-@async_data_request(transformer=no_transform)
+@async_data_request(transformers=[no_transform])
 async def async_get_distinct_in_field(asset_class: AssetClass, field: str) -> List[str]:
     """
     Asynchronously get all distinct values in field.
