@@ -7,14 +7,16 @@ from algora.common.base import Base
 class ProjectPackageRequest(Base):
     name: str
     version: str
-    tag: ProjectPackageTag
+    tag: Optional[ProjectPackageTag]
+    path: str
 
 
 class ProjectPackageResponse(Base):
     id: str
     name: str
     version: str
-    tag: ProjectPackageTag
+    tag: Optional[ProjectPackageTag]
+    path: str
     created_by: str
     created_at: int
     updated_by: Optional[str]
