@@ -39,7 +39,7 @@ class PaymentFrequency(BaseEnum):
         elif self == PaymentFrequency.ANNUALLY:
             return 1
         else:
-            raise Exception(f"Payment frequency type {self} not supported")
+            raise Exception(f"PaymentFrequency '{self}' not supported")
 
 
 class PeriodsPerYear(BaseEnum):
@@ -57,7 +57,7 @@ class PeriodsPerYear(BaseEnum):
         elif self == PeriodsPerYear.MONTHLY:
             return 12
         else:
-            raise Exception(f"PeriodsPerYear type {self} not supported")
+            raise Exception(f"PeriodsPerYear '{self}' not supported")
 
 
 class DayCountConvention(BaseEnum):
@@ -87,7 +87,7 @@ class DayCountConvention(BaseEnum):
         elif self == DayCountConvention.ACTUAL_365_2425:
             return 365.2425
         else:
-            raise Exception(f"Day count convention type {self} not supported")
+            raise Exception(f"DayCountConvention '{self}' not supported")
 
     def __int__(self):
         return int(float(self))
