@@ -1,5 +1,6 @@
 import logging
-from typing import Any, Callable
+from functools import reduce
+from typing import Any, Callable, List
 
 from requests import Response
 
@@ -11,7 +12,7 @@ logger = logging.getLogger(__name__)
 def __process_response(
         response: Response,
         processor: Callable[[Response], Any],
-        transformer: Callable[[Any], Any]
+        transformers: List[Callable[[Any], Any]]
 ):
     if response.status_code != 200 | response.status_code != 201:
         error = ApiError(
@@ -21,4 +22,4 @@ def __process_response(
         raise error
 
     data = processor(response)
-    return transformer(data)
+    return reduce(lambda res, fxn: fxn(res), transformers, data)
