@@ -9,6 +9,8 @@ from aiohttp import ClientResponse
 from pandas import DataFrame
 from requests import Response
 
+from algora.common.errors import ApiError
+
 
 def coalesce(*args):
     """
@@ -94,6 +96,22 @@ def no_transform(data: Dict[str, Any]) -> Dict[str, Any]:
     return data
 
 
+def data_required_transform(data: Dict[str, Any]) -> Dict[str, Any]:
+    """
+    Passthrough data without any transformation.
+
+    Args:
+        data (Dict[str, Any]): Input data
+
+    Returns:
+        Dict[str, Any]: Output data
+    """
+    if len(data) <= 0:
+        raise ApiError(f'There are no results for the data you are querying at this time')
+
+    return data
+
+
 async def build_response_obj(aio_response: ClientResponse) -> Response:
     """
     Construct a requests Response object from an aiohttp Client Response object
